@@ -1,6 +1,6 @@
 from django.contrib import admin
-from edc_model_admin import SimpleHistoryAdmin
 from edc_model_admin.dashboard import ModelAdminSubjectDashboardMixin
+from edc_model_admin.history import SimpleHistoryAdmin
 
 from .admin_site import edc_offstudy_admin
 from .models import SubjectOffstudy
