@@ -1,5 +1,5 @@
 from edc_consent.constants import CONSENT_WITHDRAWAL
-from edc_constants.constants import DEAD
+from edc_constants.constants import DEAD, OTHER
 from edc_visit_tracking.constants import COMPLETED_PROTOCOL_VISIT, LOST_VISIT
 
 OFFSTUDY_REASONS = (
@@ -7,4 +7,5 @@ OFFSTUDY_REASONS = (
     (COMPLETED_PROTOCOL_VISIT, "Completed protocol"),
     (CONSENT_WITHDRAWAL, "Consent withdrawn"),
     (DEAD, "Deceased"),
+    (OTHER, "Other, please specify ..."),
 )
